==> haskell-warp-tls-3.4.9-182-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-JVISKmEZvcO6IYRXCC9qXI
key:                  warp-tls-3.4.9-JVISKmEZvcO6IYRXCC9qXI
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  399416dd533c58b7de7d4f8564d1972b
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-JVISKmEZvcO6IYRXCC9qXI
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    recv-0.1.1-2zF7O1pwsoXGqfuMlLk1gB
    streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5
    tls-2.0.6-CMnie4Wyps5DmePV9nSMbU
    tls-session-manager-0.0.6-IToj1vuJmt6HbDWjOxqNUV
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63 warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.4.9-184-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-2veOLdXDg7lJ7FhpKG6TqU
key:                  warp-tls-3.4.9-2veOLdXDg7lJ7FhpKG6TqU
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  fe93e296e70a09dbe6742e87c84f9f03
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-2veOLdXDg7lJ7FhpKG6TqU
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X
    recv-0.1.1-BGi4hrFuNwtDkKnYHj9ng0
    streaming-commons-0.2.3.1-p6JZxPGlgm2ju1b9E77qr
    tls-2.0.6-JDpPGrffkyAB1IreS7llis
    tls-session-manager-0.0.6-DHDMCt9eZvUB3GmV77cUxT
    unliftio-0.2.25.1-DOqhOSuyr6GEMTQhxoBZ0V
    wai-3.2.4-BLc210LwMQhDvJHRqgIjev warp-3.4.0-Js0YTJVu1i5Lh7vUHNAyGE

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
